# New in 0.15.5 (2022-04-06)

## Changes

-   Add common types file [#1467].
-   New default is to not pin memory during training when using a GPU. This is much better for shared GPU environments without any performance regression [#1473].

## Bug fixes

-   Fix LDA user guide bugs [#1479].
-   Fix unnecessary warnings, double logging [#1475].

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1479]: https://github.com/YosefLab/scvi-tools/pull/1479
[#1475]: https://github.com/YosefLab/scvi-tools/pull/1475
[#1467]: https://github.com/YosefLab/scvi-tools/pull/1467
[#1473]: https://github.com/YosefLab/scvi-tools/pull/1473
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
